Struct CacheKeyFlags
pub struct CacheKeyFlags(/* private fields */);Expand description
Flags that change rendering
Implementations
impl CacheKeyFlags
impl CacheKeyFlags
pub const FAKE_ITALIC: CacheKeyFlags
pub const FAKE_ITALIC: CacheKeyFlags
Skew by 14 degrees to synthesize italic
pub const DISABLE_HINTING: CacheKeyFlags
pub const DISABLE_HINTING: CacheKeyFlags
Disable hinting
pub const PIXEL_FONT: CacheKeyFlags
pub const PIXEL_FONT: CacheKeyFlags
Render as a pixel font
impl CacheKeyFlags
impl CacheKeyFlags
pub const fn empty() -> CacheKeyFlags
pub const fn empty() -> CacheKeyFlags
Get a flags value with all bits unset.
pub const fn all() -> CacheKeyFlags
pub const fn all() -> CacheKeyFlags
Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<CacheKeyFlags>
pub const fn from_bits(bits: u32) -> Option<CacheKeyFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> CacheKeyFlags
pub const fn from_bits_truncate(bits: u32) -> CacheKeyFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> CacheKeyFlags
pub const fn from_bits_retain(bits: u32) -> CacheKeyFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<CacheKeyFlags>
pub fn from_name(name: &str) -> Option<CacheKeyFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: CacheKeyFlags) -> bool
pub const fn intersects(&self, other: CacheKeyFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: CacheKeyFlags) -> bool
pub const fn contains(&self, other: CacheKeyFlags) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: CacheKeyFlags)
pub fn insert(&mut self, other: CacheKeyFlags)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: CacheKeyFlags)
pub fn remove(&mut self, other: CacheKeyFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: CacheKeyFlags)
pub fn toggle(&mut self, other: CacheKeyFlags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: CacheKeyFlags, value: bool)
pub fn set(&mut self, other: CacheKeyFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: CacheKeyFlags) -> CacheKeyFlags
pub const fn intersection(self, other: CacheKeyFlags) -> CacheKeyFlags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: CacheKeyFlags) -> CacheKeyFlags
pub const fn union(self, other: CacheKeyFlags) -> CacheKeyFlags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: CacheKeyFlags) -> CacheKeyFlags
pub const fn difference(self, other: CacheKeyFlags) -> CacheKeyFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: CacheKeyFlags) -> CacheKeyFlags
pub const fn symmetric_difference(self, other: CacheKeyFlags) -> CacheKeyFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> CacheKeyFlags
pub const fn complement(self) -> CacheKeyFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl CacheKeyFlags
impl CacheKeyFlags
pub const fn iter(&self) -> Iter<CacheKeyFlags>
pub const fn iter(&self) -> Iter<CacheKeyFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<CacheKeyFlags>
pub const fn iter_names(&self) -> IterNames<CacheKeyFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.